/*
 * Copyright (c) 2005-2006 Compuware Corporation and others.
 * All rights reserved. This program and the accompanying 
 * materials are made available under the terms of the 
 * Eclipse Public License v1.0 which accompanies this 
 * distribution, and is available at:
 * http://www.eclipse.org/legal/epl-v10.html 
 * 
 * Contributors:
 *     Compuware Corporation - initial API and implementation
 *
 * CVS Attributes:
 * $Author: doflynn $
 * $Date: 2006/12/15 20:51:31 $
 * $Id: ServiceConnectionParameters.java,v 1.1 2006/12/15 20:51:31 doflynn Exp $
 * $Revision: 1.1 $
 */
package org.eclipse.corona.soa.client.util;

/**
 * @author cwpl-pjaworow
 * 
 */
public class ServiceConnectionParameters {

	/** */
	private String serverUri = null;

	/** */
	private String proxyHost = null;

	/** */
	private int proxyPort = -1;

	/** */
	private String proxyUserName = null;

	/** */
	private String proxyUserPass = null;

	//glenn added 
	private Class serviceProxyClass = null;

	//glenn added 
	private String serviceName = null;	

	//glenn added 
	private String serviceNameSpace = null;	
	
	/**
	 * Constructor.<br>
	 * NOTE: using this constructor yuo'll NOT use the proxy.
	 * @param coronaHost host to wich service shoudl be connected.
	 */
//	public ServiceConnectionParameters(String coronaHost) {
//		this(coronaHost, null, -1, null, null);
//	}

	public ServiceConnectionParameters(String coronaHost, String serviceName, String serviceNameSpace, Class serviceProxyClass) {
		this(coronaHost, serviceName, serviceNameSpace, serviceProxyClass, null, -1, null, null);
	}
	
	/**
	 * Constructor.<br>
	 * NOTE: using this constructor you'll use the proxy with anonymous user.
	 * @param coronaHost host to wich service shoudl be connected.
	 * @param proxyHost proxy host.
	 * @param proxyPort proxy port.
	 */
	public ServiceConnectionParameters(String coronaHost, String serviceName, String serviceNameSpace, Class serviceProxyClass, String proxyHost, int proxyPort) {
		this(coronaHost, serviceName, serviceNameSpace, serviceProxyClass, proxyHost, proxyPort, null, null);
	}

	/**
	 * Constructor.<br>
	 * NOTE: using this constructor you'll use the proxy with anonymous user.
	 * @param coronaHost host to wich service shoudl be connected.
	 * @param proxyHost proxy host.
	 * @param proxyPort proxy port.
	 * @param proxyUserName proxy user name.
	 * @param proxyUserPassword proxy user password.
	 */
	public ServiceConnectionParameters(String coronaHost, String serviceName, String serviceNameSpace, Class serviceProxyClass, String proxyHost, int proxyPort, String proxyUserName,
			String proxyUserPassword) {
		this.serverUri = coronaHost;
		this.serviceName = serviceName;
		this.serviceNameSpace = serviceNameSpace;
		this.serviceProxyClass = serviceProxyClass;
		this.proxyHost = proxyHost;
		this.proxyPort = proxyPort;
		this.proxyUserName = proxyUserName;
		this.proxyUserPass = proxyUserPassword;
	}

	/**
	 * Getter method for the coronaHost.
	 * 
	 * @return the coronaHost
	 */
	public String getServerUri() {
		return serverUri;
	}

	/**
	 * Setter method for the coronaHost.
	 * 
	 * @param coronaHost
	 *            the coronaHost to set
	 */
	public void setServerUri(String coronaHost) {
		this.serverUri = coronaHost;
	}

	/**
	 * Getter method for the proxyHost.
	 * 
	 * @return the proxyHost
	 */
	public String getProxyHost() {
		return proxyHost;
	}

	/**
	 * Setter method for the proxyHost.
	 * 
	 * @param proxyHost
	 *            the proxyHost to set
	 */
	public void setProxyHost(String proxyHost) {
		this.proxyHost = proxyHost;
	}

	/**
	 * Getter method for the proxyUserName.
	 * 
	 * @return the proxyUserName
	 */
	public String getProxyUserName() {
		return proxyUserName;
	}

	/**
	 * Setter method for the proxyUserName.
	 * 
	 * @param proxyUserName
	 *            the proxyUserName to set
	 */
	public void setProxyUserName(String proxyUserName) {
		this.proxyUserName = proxyUserName;
	}

	/**
	 * Getter method for the proxyUserPass.
	 * 
	 * @return the proxyUserPass
	 */
	public String getProxyUserPass() {
		return proxyUserPass;
	}

	/**
	 * Setter method for the proxyUserPass.
	 * 
	 * @param proxyUserPass
	 *            the proxyUserPass to set
	 */
	public void setProxyUserPass(String proxyUserPass) {
		this.proxyUserPass = proxyUserPass;
	}

	/**
	 * Getter method for the proxyPort.
	 * 
	 * @return the proxyPort
	 */
	public int getProxyPort() {
		return proxyPort;
	}

	/**
	 * Setter method for the proxyPort.
	 * 
	 * @param proxyPort
	 *            the proxyPort to set
	 */
	public void setProxyPort(int proxyPort) {
		this.proxyPort = proxyPort;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public int hashCode() {
		int result = 0;
		if (serverUri != null)
			result = 7 * result + serverUri.hashCode();
		if (proxyHost != null) {
			result = 7 * result + proxyHost.hashCode();
			result = 7 * result + proxyPort;
		}
		if (proxyUserName != null)
			result = 7 * result + proxyUserName.hashCode();
		if (proxyUserPass != null)
			result = 7 * result + proxyUserPass.hashCode();
		return result;
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean equals(Object obj) {
		if (!(obj instanceof ServiceConnectionParameters))
			return false;
		ServiceConnectionParameters scp = (ServiceConnectionParameters) obj;
		return ((serverUri == scp.serverUri || (serverUri != null && serverUri.equals(scp.serverUri)))
				&& (proxyHost == scp.proxyHost || (proxyHost != null && proxyHost.equals(scp.proxyHost)))
				&& (scp.proxyPort == proxyPort)
				&& (proxyUserName == scp.proxyUserName || (proxyUserName != null && proxyUserName.equals(scp.proxyUserName))) 
				&& (proxyUserPass == scp.proxyUserPass || (proxyUserPass != null && proxyUserPass.equals(scp.proxyUserPass))));
	}

	public Class getServiceProxyClass() {
		return serviceProxyClass;
	}

	public void setServiceProxyClass(Class serviceProxyClass) {
		this.serviceProxyClass = serviceProxyClass;
	}

	public String getServiceName() {
		return serviceName;
	}

	public void setServiceName(String serviceName) {
		this.serviceName = serviceName;
	}

	public String getServiceNameSpace() {
		return serviceNameSpace;
	}

	public void setServiceNameSpace(String serviceNameSpace) {
		this.serviceNameSpace = serviceNameSpace;
	}
	
	
}
