package org.eclipse.corona.soa.service.example;

import org.apache.muse.osgi.soa.core.SOAPProvider;
import org.apache.muse.osgi.soa.core.web.WebApp;
import org.eclipse.core.runtime.Plugin;
import org.eclipse.corona.log.CoronaLogService;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceEvent;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceEvent;
import org.osgi.framework.ServiceListener;
import org.osgi.framework.ServiceReference;
import org.apache.muse.osgi.soa.core.SOAPProvider;
import org.apache.muse.osgi.soa.core.web.WebApp;
import org.eclipse.corona.soa.example.shared.ISOAExample;
import org.eclipse.corona.tools.osgi.BundleHelpers;

/**
 * The activator class controls the plug-in life cycle
 */
public class Activator extends Plugin implements ServiceListener {

	// The plug-in ID
	public static final String PLUGIN_ID = "org.eclipse.corona.soa.service.example";
	private static final String SOAP_SERVICE_FILTER = "(objectclass=org.apache.muse.osgi.soa.core.SOAPProvider)";

	// The shared instance
	private static Activator plugin;
	private BundleContext bundleContext = null;

	private static CoronaLogService logService = new CoronaLogService();
	private ServiceReference soapProviderReference;
	private SOAPProvider soapProvider;
	
	/**
	 * The constructor
	 */
	public Activator() {
		plugin = this;
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.core.runtime.Plugins#start(org.osgi.framework.BundleContext)
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);
		bundleContext = context;
//		Bundle[] bundles = context.getBundles();
//		BundleHelpers.startBundles(kickstart);
		
		soapProviderReference = context.getServiceReference("org.apache.muse.osgi.soa.core.SOAPProvider");
		if(soapProviderReference != null){
			soapProvider = (SOAPProvider)context.getService(soapProviderReference);
			deploy();
		}
//		context.addServiceListener(this,SOAP_SERVICE_FILTER);
		context.addServiceListener(this, SOAP_SERVICE_FILTER);
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.core.runtime.Plugin#stop(org.osgi.framework.BundleContext)
	 */
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		
		super.stop(context);

		logService.stop(context);
		
	}

	/**
	 * Returns the shared instance
	 *
	 * @return the shared instance
	 */
	public static Activator getDefault() {
		return plugin;
	}

	private void deploy(){
		//Ideally, create a web app, and set the default handler chain (add security, say)
		try {
			WebApp app = soapProvider.getWebApp(bundleContext.getBundle(), "sdo", true);
			soapProvider.deployService(app, "SoaExample", ISOAExample.class, new Example(), null);
			
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}

	
	/** 
	 * Get the Corona log service for this plug-in
	 * 
	 * @return
	 */
	public static CoronaLogService getLogService() {
		return logService;
	}
	
	public void serviceChanged(ServiceEvent event) {
		switch(event.getType()){
		case ServiceEvent.REGISTERED:
			soapProviderReference = event.getServiceReference();
			soapProvider = (SOAPProvider)bundleContext.getService(soapProviderReference);
			deploy();
			break;
		case ServiceEvent.MODIFIED:
			break;
		case ServiceEvent.UNREGISTERING:
			break;
		}
	}

	/**
	 * Getter method for bundle context.
	 * @return BundleContext of this plugin.
	 */
	public BundleContext getBundleContext() {
		return this.bundleContext;
	}
	
	
}
